@@ -7,7 +7,9 @@ from carbon3d.api.attachments_api import AttachmentsApi
 from carbon3d.api.builds_api import BuildsApi
 from carbon3d.api.models_api import ModelsApi
 from carbon3d.api.orders_api import OrdersApi
+from carbon3d.api.part_orders_api import PartOrdersApi
 from carbon3d.api.parts_api import PartsApi
+from carbon3d.api.print_orders_api import PrintOrdersApi
 from carbon3d.api.printed_parts_api import PrintedPartsApi
 from carbon3d.api.printers_api import PrintersApi
 from carbon3d.api.prints_api import PrintsApi
